@@ -2,21 +2,24 @@ package Net::Whois::Object::Inet6Num;
 
 use base qw/Net::Whois::Object/;
 
-# From ripe-223 
+# http://www.ripe.net/data-tools/support/documentation/update-ref-manual#section-12
+# http://www.apnic.net/apnic-info/whois_search/using-whois/guide/inet6num
 #
 # inet6num:      [mandatory]  [single]     [primary/look-up key]
 # netname:       [mandatory]  [single]     [lookup key]
 # descr:         [mandatory]  [multiple]   [ ]
 # country:       [mandatory]  [multiple]   [ ]
+# org:           [optional]   [single]     [inverse key]
 # admin-c:       [mandatory]  [multiple]   [inverse key]
 # tech-c:        [mandatory]  [multiple]   [inverse key]
-# rev-srv:       [optional]   [multiple]   [inverse key]
-# status:        [generated]  [single]     [ ]
+# status:        [mandatory]  [single]     [ ]
 # remarks:       [optional]   [multiple]   [ ]
 # notify:        [optional]   [multiple]   [inverse key]
 # mnt-by:        [mandatory]  [multiple]   [inverse key]
 # mnt-lower:     [optional]   [multiple]   [inverse key]
 # mnt-routes:    [optional]   [multiple]   [inverse key]
+# mnt-domains:   [optional]   [multiple]   [inverse key]
+# mnt-irt:       [optional]   [multiple]   [inverse key]
 # changed:       [mandatory]  [multiple]   [ ]
 # source:        [mandatory]  [single]     [ ]
 
@@ -58,6 +61,11 @@ sub new {
 Accessor to the inet6num attribute.
 Accepts an optional inet6num value, always return the current inet6num value.
 
+The inet6num attribute specifies a range of IPv6 addresses that the
+inet6num object presents. The range may be a single address.
+
+Addresses can only be expressed in prefix notation
+
 =cut
 
 sub inet6num {
@@ -71,6 +79,10 @@ sub inet6num {
 Accessor to the netname attribute.
 Accepts an optional netname, always return the current netname.
 
+The netname attribute is the name of a range of IP address space. It is
+recommended that the same netname is used for any set of assignment ranges
+used for a common purpose.
+
 =cut
 
 sub netname {
@@ -85,6 +97,9 @@ Accessor to the descr attribute.
 Accepts an optional descr to be added to the descr array,
 always return the current descr array.
 
+Description of the organization allocated or assigned the address space shown
+in the inet6num.
+
 =cut
 
 sub descr {
@@ -99,6 +114,12 @@ Accessor to the country attribute.
 Accepts an optional country to be added to the country array,
 always return the current country array.
 
+The country attribute identifies the country. It has never been specified
+if this is the country where the addresses are used, where the issuing
+organisation is based or some transit country in between. There are no rules
+defined for this attribute. It cannot therefore be used in any reliable way to
+map IP addresses to countries.
+
 =cut
 
 sub country {
@@ -107,12 +128,35 @@ sub country {
     return \@{ $self->{country} };
 }
 
+=head2 B<org( [$org] )>
+
+Accessor to the org attribute.
+Accepts an optional org, always return the current org.
+
+Only a single value for the org attribute is allowed in the inet6num
+object. This is to ensure only one organisation is responsible for this
+resource.
+
+=cut
+
+sub org {
+    my ( $self, $org ) = @_;
+    $self->{org} = $org if defined $org;
+    return $self->{org};
+}
+
 =head2 B<admin_c( [$contact] )>
 
 Accessor to the admin_c attribute.
 Accepts an optional contact to be added to the admin_c array,
 always return the current admin_c array.
 
+The NIC-handle of an on-site contact 'person' object. As more than one person
+often fulfills a role function, there may be more than one admin_c listed.
+
+An administrative contact (admin_c) must be someone who is physically
+located at the site of the network.
+
 =cut
 
 sub admin_c {
@@ -127,6 +171,13 @@ Accessor to the tech_c attribute.
 Accepts an optional contact to be added to the tech_c array,
 always return the current tech_c array.
 
+The NIC-handle of a technical contact 'person' or 'role' object.  As more than
+one person often fulfills a role function, there may be more than one tech_c
+listed.
+
+A technical contact (tech_c) must be a person responsible for the
+day-to-day operation of the network, but does not need to be
+
 =cut
 
 sub tech_c {
@@ -135,25 +186,30 @@ sub tech_c {
     return \@{ $self->{tech_c} };
 }
 
-=head2 B<rev_srv( [$serv] )>
-
-Accessor to the rev_srv attribute.
-Accepts an optional serv to be added to the rev_srv array,
-always return the current rev_srv array.
-
-=cut
-
-sub rev_srv {
-    my ( $self, $serv ) = @_;
-    push @{ $self->{rev_srv} }, $serv if defined $serv;
-    return \@{ $self->{rev_srv} };
-}
-
 =head2 B<status( [$status] )>
 
 Accessor to the status attribute.
 Accepts an optional status, always return the current status.
 
+The status attribute indicates where the address range represented by an
+inet6num object sits in a hierarchy and how it is used.
+
+Status can have one of these values:
+
+=over 4
+
+=item ALLOCATED-BY-RIR
+
+=item ALLOCATED-BY-LIR
+
+=item ASSIGNED
+
+=item ASSIGNED ANYCAST
+
+=item ASSIGNED PI
+
+=back
+
 =cut
 
 sub status {
@@ -168,6 +224,9 @@ Accessor to the remarks attribute.
 Accepts an optional remark to be added to the remarks array,
 always return the current remarks array.
 
+General remarks. May include a URL or instructions on where to send abuse
+complaints.
+
 =cut
 
 sub remarks {
@@ -182,6 +241,9 @@ Accessor to the notify attribute.
 Accepts an optional notify value to be added to the notify array,
 always return the current notify array.
 
+The email address to which notifications of changes to this object should be
+sent.
+
 =cut
 
 sub notify {
@@ -210,6 +272,9 @@ Accessor to the mnt_lower attribute.
 Accepts an optional mnt_lower value to be added to the mnt_lower array,
 always return the current mnt_lower array.
 
+Sometimes there is a hierarchy of maintainers. In these cases, mnt-lower is
+used as well as 'mnt-by.'
+
 =cut
 
 sub mnt_lower {
@@ -224,6 +289,10 @@ Accessor to the mnt_routes attribute.
 Accepts an optional mnt_route to be added to the mnt_routes array,
 always return the current mnt_routes array.
 
+The identifier of a registered Mntner object used to control the creation of
+Route6 objects associated with the address range specified by the Inet6num
+object.
+
 =cut
 
 sub mnt_routes {
@@ -232,12 +301,56 @@ sub mnt_routes {
     return \@{ $self->{mnt_routes} };
 }
 
+=head2 B<mnt_domains( [$mnt_route] )>
+
+Accessor to the mnt_domains attribute.
+Accepts an optional mnt_route to be added to the mnt_domains array,
+always return the current mnt_domains array.
+
+The identifier of a registered Mntner object used to control the creation of
+Domain objects associated with the address range specified by the Inet6num
+object.
+
+=cut
+
+sub mnt_domains {
+    my ( $self, $mnt_route ) = @_;
+    push @{ $self->{mnt_domains} }, $mnt_route if defined $mnt_route;
+    return \@{ $self->{mnt_domains} };
+}
+
+=head2 B<mnt_irt( [$mnt_irt] )>
+
+Accessor to the mnt_irt attribute.
+Accepts an optional mnt_irt to be added to the mnt_irt array,
+always return the current mnt_irt array.
+
+mnt_irt references an Irt object. Authorisation is required from the Irt
+object to be able to add this reference.
+
+=cut
+
+sub mnt_irt {
+    my ( $self, $mnt_irt ) = @_;
+    push @{ $self->{mnt_irt} }, $mnt_irt if defined $mnt_irt;
+    return \@{ $self->{mnt_irt} };
+}
+
 =head2 B<changed( [$changed] )>
 
 Accessor to the changed attribute.
 Accepts an optional changed value to be added to the changed array,
 always return the current changed array.
 
+The email address of who last updated the database object and the date it
+occurred.
+
+Every time a change is made to a database object, this attribute will show
+the email address of the person who made those changes.
+Please use the address format specified in RFC 822 - Standard for
+the Format of ARPA Internet Text Message and provide the date
+format using one of the following two formats: YYYYMMDD or YYMMDD.
+
 =cut
 
 sub changed {
@@ -251,6 +364,8 @@ sub changed {
 Accessor to the source attribute.
 Accepts an optional source, always return the current source.
 
+The database where the object is registered.
+
 =cut
 
 sub source {
@@ -259,19 +374,4 @@ sub source {
     return $self->{source};
 }
 
-=head2 B<mnt_irt( [$mnt_irt] )>
-
-Accessor to the mnt_irt attribute.
-Accepts an optional mnt_irt, always return the current mnt_irt.
-The identifier of a registered 'mntner' object used to provide information
-about a Computer Security Incident Response Team (CSIRT).
-
-=cut
-
-sub mnt_irt {
-    my ( $self, $mnt_irt ) = @_;
-    $self->{mnt_irt} = $mnt_irt if defined $mnt_irt;
-    return $self->{mnt_irt};
-}
-
 1;
